@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90.2.1 1997/02/27 17:49:41 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.4 1997/04/15 23:45:17 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -44,6 +44,7 @@ static void
 clientLookupDstIPDone(int fd, const ipcache_addrs * ia, void *data)
 {
     icpStateData *icpState = data;
+    icpState->ip_lookup_pending = 0;
     debug(33, 5, "clientLookupDstIPDone: FD %d, '%s'\n",
 	fd,
 	icpState->url);
@@ -190,6 +191,7 @@ clientAccessCheck(icpStateData * icpState, void (*handler) (icpStateData *, int)
 	answer = aclCheck(HTTPAccessList, ch);
 	if (ch->state[ACL_DST_IP] == ACL_LOOKUP_NEED) {
 	    ch->state[ACL_DST_IP] = ACL_LOOKUP_PENDING;		/* first */
+	    icpState->ip_lookup_pending = 1;
 	    ipcache_nbgethostbyname(icpState->request->host,
 		icpState->fd,
 		clientLookupDstIPDone,
@@ -228,6 +230,9 @@ clientAccessCheckDone(icpStateData * icpState, int answer)
     debug(33, 5, "clientAccessCheckDone: '%s' answer=%d\n", icpState->url, answer);
     if (answer) {
 	urlCanonical(icpState->request, icpState->url);
+	if (icpState->redirect_state != REDIRECT_NONE)
+	    fatal_dump("clientAccessCheckDone: wrong redirect_state");
+	icpState->redirect_state = REDIRECT_PENDING;
 	redirectStart(fd, icpState, clientRedirectDone, icpState);
     } else {
 	debug(33, 5, "Access Denied: %s\n", icpState->url);
@@ -259,6 +264,9 @@ clientRedirectDone(void *data, char *result)
     request_t *old_request = icpState->request;
     debug(33, 5, "clientRedirectDone: '%s' result=%s\n", icpState->url,
 	result ? result : "NULL");
+    if (icpState->redirect_state != REDIRECT_PENDING)
+	fatal_dump("clientRedirectDone: wrong redirect_state");
+    icpState->redirect_state = REDIRECT_DONE;
     if (result)
 	new_request = urlParse(old_request->method, result);
     if (new_request) {
