@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.95.2.13 1997/03/27 22:19:15 wessels Exp $
+ * $Id: squid.h,v 1.95.2.15 1997/04/24 17:41:17 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -332,12 +332,12 @@ extern int opt_no_ipcache;	/* main.c */
 extern int vhost_mode;		/* main.c */
 extern int Squid_MaxFD;		/* main.c */
 extern int Biggest_FD;		/* main.c */
+extern int select_loops;	/* main.c */
 extern const char *const version_string;	/* main.c */
 extern const char *const appname;	/* main.c */
 extern struct in_addr local_addr;	/* main.c */
 extern struct in_addr theOutICPAddr;	/* main.c */
 extern const char *const localhost;
-extern unsigned int inaddr_none;
 extern struct in_addr no_addr;	/* comm.c */
 extern int opt_udp_hit_obj;	/* main.c */
 extern int opt_mem_pools;	/* main.c */
